/*
 Demetris Christodoulou
 demetris.christodoulou@sydney.edu.au
 Graph Workflow ©
 www.graphworkflow.com
*/

version 15
cd "/Users/dchristodoulou/Documents/graphworklfow/graphs/z_hans_rosling/"

set scheme s1mono
graph set window fontface "Helvetica"
graph set window fontfaceserif "Minion Pro"

clear
use gapminder_inc_lif_pop, replace
drop if missing(lif,inc,pop)
drop if lif<20

replace inc = ln(inc)
encode region, gen(region_id)
drop country_id
encode country, gen(country_id)

// adjust marker sizes for bubble chart
expand 4
sort country_id year
replace lif=. if mod(_n,4) > 0
recode region_id (1=2) (2=3) (3=4) (4=1) if mod(_n,4) == 1
recode region_id (1=3) (2=4) (3=1) (4=2) if mod(_n,4) == 2
recode region_id (1=4) (2=1) (3=2) (4=3) if mod(_n,4) == 3

levelsof year, local(ylist)

scalar y0 = (85 + 20)/2
scalar x0 = (ln(180000) + ln(180))/2
local sopt ms(O) mlw(*.1) mlc(gs0)

cd "/Users/dchristodoulou/Documents/graphworklfow/graphs/z_hans_rosling/gapminder_png"

foreach y of local ylist {
twoway (scatteri `=y0' `=x0' "`y'" ///
        , ms(i) mlabpos(0) mlabsiz(*18) mlabc(gs14*.50)) ///
       (scatter lif inc if region_id==3  & year==`y' [fw=pop] ///
	    , `sopt' mfc("255 255 51%40")) ///
       (scatter lif inc if region_id==2 & year==`y' [fw=pop] ///
	    , `sopt' mfc("55 126 184%50")) ///
       (scatter lif inc if region_id==1    & year==`y' [fw=pop] ///
	    , `sopt' mfc("77 175 74%50")) ///
       (scatter lif inc if region_id==4  & year==`y' [fw=pop] ///
	    , `sopt' mfc("255 127 0%50")) ///
	   , ysize(8) xsize(13) ///
	   leg(pos(1) ring(1) order(4 3 2 5) row(1) size(*.75) color(gs6) ///
	       region(lc(none) fc(none) margin(none)) bmargin(l=0 t=0 b=4 r=10) ///
	       label(2 "Asia") label(3 "America") label(4 "Africa") label(5 "Europe")) ///
	   title("200 years that changed the world" ///
	        , pos(11) size(*.85) margin(l=0 t=0 b=4 r=10) ring(1) c(gs6)) ///
	   graphregion(margin(b=5 l=5 t=5 r=8) fc(gs15*.5) lc(gs0) lw(*.5)) ///
	   plotregion(margin(b=0 l=0 t=.1 r=.1) lc(gs8) fc(gs16)) ///
	   yscale(lc(none) range(15 85)) ///
	   xscale(lc(none)) ///
	   ytitle("Life expectancy at birth (years)" ///
	          , size(*.75) margin(b+2) c(gs6)) ///
	   xtitle("Log income per person (GDP/capita, inflation-adjusted US$)" ///
	          , size(*.75) margin(t+2) c(gs6)) ///
	   xlabel(`=ln(180)' "ln($180)" `=ln(1800)' "ln($1,800)" ///
	          `=ln(18000)' "ln($18,000)"  `=ln(180000)' "ln($180,000)" ///
			  , labsize(*.65) grid glw(*.25)  tlc(gs8) glc(gs14) labc(gs8)) ///
	   ylabel(10 " " 20(10)90, angle(0) labsize(*.65) ///
	         grid glw(*.25) tlc(gs8) glc(gs14) labc(gs8))
graph export year`y'.png,replace
}

exit

Source: https://www.gapminder.org/data/
1. gapminder_income_per_person_gdppercapita_ppp_inflation_adjusted
2. gapminder_life_expectancy_years
3. gapminder_population_total
